@@ -52,8 +52,8 @@ public:
 
 	void tearDown()
 	{
-		log4cxx::spi::LoggerRepositoryPtr rep = logger->getLoggerRepository().lock();
-		if (rep) {
+		if (auto rep = logger->getLoggerRepository())
+		{
 			rep->resetConfiguration();
 		}
 	}
@@ -88,7 +88,7 @@ public:
 		i++;
 		LOG4CXX_DEBUG(logger, "Message " << i);
 
-		const File OUTPUT("output/temp");
+		const File OUTPUT("output/customlogger");
 		std::string witness("witness/customLogger.");
 		witness.append(number);
 		const File WITNESS(witness);
