@@ -67,8 +67,8 @@ public:
 
 	void tearDown()
 	{
-		log4cxx::spi::LoggerRepositoryPtr rep = root->getLoggerRepository().lock();
-		if (rep) {
+		if (auto rep = root->getLoggerRepository())
+		{
 			rep->resetConfiguration();
 		}
 	}
@@ -102,7 +102,7 @@ public:
 				LOG4CXX_TEST_STR("log4j"), LOG4CXX_TEST_STR("log4cxx"));
 		}
 
-		LOGUNIT_ASSERT(Compare::compare(LOG4CXX_FILE("output/temp"),
+		LOGUNIT_ASSERT(Compare::compare(LOG4CXX_FILE("output/l7d1"),
 				LOG4CXX_FILE("witness/l7d.1")));
 	}
 
